@@ -1,26 +1,25 @@
 use std::{rc::Rc, sync::Arc};
 
 use floem::{
+    View,
     event::{Event, EventListener},
     reactive::{
-        create_effect, create_memo, create_rw_signal, Memo, ReadSignal, RwSignal,
-        Scope, SignalGet, SignalUpdate, SignalWith,
+        Memo, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        create_effect, create_memo, create_rw_signal,
     },
     style::CursorStyle,
     views::{
-        container, dyn_stack, label, scroll, stack, text, virtual_stack, Decorators,
-        VirtualDirection, VirtualItemSize,
+        Decorators, container, dyn_stack, label, scroll, stack, text, virtual_stack,
     },
-    View,
 };
 use lapce_core::mode::Modes;
 
 use crate::{
     command::LapceCommand,
-    config::{color::LapceColor, LapceConfig},
+    config::{LapceConfig, color::LapceColor},
     keypress::{
-        keymap::{KeyMap, KeyMapPress},
         KeyPressData,
+        keymap::{KeyMap, KeyMapPress},
     },
     main_split::Editors,
     text_input::TextInputBuilder,
@@ -283,7 +282,7 @@ pub fn keymap_view(editors: Editors, common: Rc<CommonData>) -> impl View {
         container(
             text_input_view
                 .placeholder(|| "Search Key Bindings".to_string())
-                .keyboard_navigatable()
+                .keyboard_navigable()
                 .request_focus(|| {})
                 .style(move |s| {
                     s.width_pct(100.0)
@@ -347,8 +346,6 @@ pub fn keymap_view(editors: Editors, common: Rc<CommonData>) -> impl View {
         container(
             scroll(
                 virtual_stack(
-                    VirtualDirection::Vertical,
-                    VirtualItemSize::Fixed(Box::new(ui_line_height)),
                     items,
                     |(i, (cmd, keymap)): &(
                         usize,
@@ -356,6 +353,7 @@ pub fn keymap_view(editors: Editors, common: Rc<CommonData>) -> impl View {
                     )| { (*i, cmd.kind.str(), keymap.clone()) },
                     view_fn,
                 )
+                .item_size_fixed(ui_line_height)
                 .style(|s| s.flex_col().width_pct(100.0)),
             )
             .style(|s| s.absolute().size_pct(100.0, 100.0)),
@@ -410,6 +408,7 @@ fn keyboard_picker_view(
                         s.padding_horiz(5.0)
                             .padding_vert(1.0)
                             .margin_right(5.0)
+                            .height(ui_line_height.get() as f32)
                             .border(1.0)
                             .border_radius(6.0)
                             .border_color(
@@ -424,7 +423,7 @@ fn keyboard_picker_view(
                     .justify_center()
                     .width_pct(100.0)
                     .margin_top(20.0)
-                    .height(ui_line_height.get() as f32 + 16.0)
+                    .height((ui_line_height.get() as f32) * 1.2)
                     .border(1.0)
                     .border_radius(6.0)
                     .border_color(config.color(LapceColor::LAPCE_BORDER))
@@ -514,22 +513,23 @@ fn keyboard_picker_view(
                 .background(config.color(LapceColor::PANEL_BACKGROUND))
         }),
     )
-    .keyboard_navigatable()
+    .keyboard_navigable()
     .on_event_stop(EventListener::KeyDown, move |event| {
         if let Event::KeyDown(key_event) = event {
             if let Some(keypress) = KeyPressData::keypress(key_event) {
-                let keypress = keypress.keymap_press();
-                picker.keys.update(|keys| {
-                    if let Some((last_key, last_key_confirmed)) = keys.last() {
-                        if !*last_key_confirmed && last_key.is_modifiers() {
-                            keys.pop();
+                if let Some(keypress) = keypress.keymap_press() {
+                    picker.keys.update(|keys| {
+                        if let Some((last_key, last_key_confirmed)) = keys.last() {
+                            if !*last_key_confirmed && last_key.is_modifiers() {
+                                keys.pop();
+                            }
                         }
-                    }
-                    if keys.len() == 2 {
-                        keys.clear();
-                    }
-                    keys.push((keypress, false));
-                })
+                        if keys.len() == 2 {
+                            keys.clear();
+                        }
+                        keys.push((keypress, false));
+                    })
+                }
             }
         }
     })
@@ -548,7 +548,8 @@ fn keyboard_picker_view(
             .items_center()
             .justify_center()
             .apply_if(picker.keymap.with(|keymap| keymap.is_none()), |s| s.hide())
-    });
+    })
+    .debug_name("keyboard picker");
 
     let id = view.id();
     create_effect(move |_| {
