@@ -3,7 +3,7 @@ use std::{rc::Rc, sync::Arc};
 use floem::{
     kurbo::Size,
     reactive::{
-        use_context, Memo, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith,
+        Memo, RwSignal, Scope, SignalGet, SignalUpdate, SignalWith, use_context,
     },
 };
 use serde::{Deserialize, Serialize};
@@ -37,7 +37,9 @@ pub fn default_panel_order() -> PanelOrder {
             PanelKind::Terminal,
             PanelKind::Search,
             PanelKind::Problem,
-            PanelKind::CallHierarchy
+            PanelKind::CallHierarchy,
+            PanelKind::References,
+            PanelKind::Implementation
         ],
     );
     order.insert(
