@@ -1,18 +1,18 @@
 use std::{rc::Rc, sync::Arc};
 
 use floem::{
+    View,
     event::EventListener,
     peniko::Color,
     reactive::{
-        create_rw_signal, ReadSignal, RwSignal, SignalGet, SignalUpdate, SignalWith,
+        ReadSignal, RwSignal, SignalGet, SignalUpdate, SignalWith, create_rw_signal,
     },
     style::CursorStyle,
     text::Style as FontStyle,
     views::{
-        container, dyn_stack, label, scroll, stack, svg, text, virtual_stack,
-        Decorators, VirtualDirection, VirtualItemSize,
+        Decorators, container, dyn_stack, label, scroll, stack, svg, text,
+        virtual_stack,
     },
-    View,
 };
 use lapce_rpc::{
     dap_types::{DapId, ThreadId},
@@ -23,7 +23,7 @@ use super::{data::PanelSection, position::PanelPosition, view::PanelBuilder};
 use crate::{
     app::clickable_icon,
     command::InternalCommand,
-    config::{color::LapceColor, icon::LapceIcons, LapceConfig},
+    config::{LapceConfig, color::LapceColor, icon::LapceIcons},
     debug::{DapVariable, RunDebugMode, StackTraceData},
     editor::location::{EditorLocation, EditorPosition},
     listener::Listener,
@@ -320,7 +320,7 @@ fn debug_processes(
                         .hover(|s| {
                             s.cursor(CursorStyle::Pointer).background(
                                 (config.color(LapceColor::PANEL_HOVERED_BACKGROUND))
-                                    .with_alpha_factor(0.3),
+                                    .multiply_alpha(0.3),
                             )
                         })
                 })
@@ -338,8 +338,6 @@ fn variables_view(window_tab_data: Rc<WindowTabData>) -> impl View {
     container(
         scroll(
             virtual_stack(
-                VirtualDirection::Vertical,
-                VirtualItemSize::Fixed(Box::new(move || ui_line_height.get())),
                 move || {
                     let dap = terminal.get_active_dap(true);
                     dap.map(|dap| {
@@ -445,6 +443,7 @@ fn variables_view(window_tab_data: Rc<WindowTabData>) -> impl View {
                     })
                 },
             )
+            .item_size_fixed(move || ui_line_height.get())
             .style(|s| s.flex_col().min_width_full()),
         )
         .style(|s| s.absolute().size_full()),
