@@ -10,37 +10,28 @@ use std::{
     fs,
     path::{Path, PathBuf},
     sync::{
-        atomic::{AtomicBool, AtomicU64, AtomicUsize, Ordering},
         Arc,
+        atomic::{AtomicBool, AtomicU64, AtomicUsize, Ordering},
     },
     time::Duration,
 };
 
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use crossbeam_channel::{Receiver, Sender};
 use dyn_clone::DynClone;
 use flate2::read::GzDecoder;
 use lapce_core::directory::Directory;
 use lapce_rpc::{
+    RequestId, RpcError,
     core::CoreRpcHandler,
     dap_types::{self, DapId, RunDebugConfig, SourceBreakpoint, ThreadId},
     plugin::{PluginId, VoltInfo, VoltMetadata},
     proxy::ProxyRpcHandler,
     style::LineStyle,
     terminal::TermId,
-    RequestId, RpcError,
 };
 use lapce_xi_rope::{Rope, RopeDelta};
 use lsp_types::{
-    request::{
-        CallHierarchyIncomingCalls, CallHierarchyPrepare, CodeActionRequest,
-        CodeActionResolveRequest, CodeLensRequest, Completion,
-        DocumentSymbolRequest, Formatting, GotoDefinition, GotoTypeDefinition,
-        GotoTypeDefinitionParams, GotoTypeDefinitionResponse, HoverRequest,
-        InlayHintRequest, InlineCompletionRequest, PrepareRenameRequest, References,
-        Rename, Request, ResolveCompletionItem, SelectionRangeRequest,
-        SemanticTokensFullRequest, SignatureHelpRequest, WorkspaceSymbolRequest,
-    },
     CallHierarchyClientCapabilities, CallHierarchyIncomingCall,
     CallHierarchyIncomingCallsParams, CallHierarchyItem, CallHierarchyPrepareParams,
     ClientCapabilities, CodeAction, CodeActionCapabilityResolveSupport,
@@ -50,10 +41,11 @@ use lsp_types::{
     CompletionItem, CompletionItemCapability,
     CompletionItemCapabilityResolveSupport, CompletionParams, CompletionResponse,
     Diagnostic, DocumentFormattingParams, DocumentSymbolClientCapabilities,
-    DocumentSymbolParams, DocumentSymbolResponse, FormattingOptions, GotoCapability,
-    GotoDefinitionParams, GotoDefinitionResponse, Hover, HoverClientCapabilities,
-    HoverParams, InlayHint, InlayHintClientCapabilities, InlayHintParams,
-    InlineCompletionClientCapabilities, InlineCompletionParams,
+    DocumentSymbolParams, DocumentSymbolResponse, FoldingRange,
+    FoldingRangeClientCapabilities, FoldingRangeParams, FormattingOptions,
+    GotoCapability, GotoDefinitionParams, GotoDefinitionResponse, Hover,
+    HoverClientCapabilities, HoverParams, InlayHint, InlayHintClientCapabilities,
+    InlayHintParams, InlineCompletionClientCapabilities, InlineCompletionParams,
     InlineCompletionResponse, InlineCompletionTriggerKind, Location, MarkupKind,
     MessageActionItemCapabilities, ParameterInformationSettings,
     PartialResultParams, Position, PrepareRenameResponse,
@@ -68,9 +60,19 @@ use lsp_types::{
     VersionedTextDocumentIdentifier, WindowClientCapabilities,
     WorkDoneProgressParams, WorkspaceClientCapabilities, WorkspaceEdit,
     WorkspaceSymbolClientCapabilities, WorkspaceSymbolParams,
+    request::{
+        CallHierarchyIncomingCalls, CallHierarchyPrepare, CodeActionRequest,
+        CodeActionResolveRequest, CodeLensRequest, CodeLensResolve, Completion,
+        DocumentSymbolRequest, FoldingRangeRequest, Formatting, GotoDefinition,
+        GotoImplementation, GotoImplementationResponse, GotoTypeDefinition,
+        GotoTypeDefinitionParams, GotoTypeDefinitionResponse, HoverRequest,
+        InlayHintRequest, InlineCompletionRequest, PrepareRenameRequest, References,
+        Rename, Request, ResolveCompletionItem, SelectionRangeRequest,
+        SemanticTokensFullRequest, SignatureHelpRequest, WorkspaceSymbolRequest,
+    },
 };
 use parking_lot::Mutex;
-use serde::{de::DeserializeOwned, Deserialize, Serialize};
+use serde::{Deserialize, Serialize, de::DeserializeOwned};
 use serde_json::{Map, Value};
 use tar::Archive;
 use tracing::error;
@@ -121,9 +123,9 @@ pub enum PluginCatalogRpc {
         frame_id: usize,
         f: Box<
             dyn RpcCallback<
-                Vec<(dap_types::Scope, Vec<dap_types::Variable>)>,
-                RpcError,
-            >,
+                    Vec<(dap_types::Scope, Vec<dap_types::Variable>)>,
+                    RpcError,
+                >,
         >,
     },
     DidOpenTextDocument {
@@ -241,7 +243,9 @@ impl PluginCatalogRpcHandler {
     #[allow(dead_code)]
     fn handle_response(&self, id: RequestId, result: Result<Value, RpcError>) {
         if let Some(chan) = { self.pending.lock().remove(&id) } {
-            let _ = chan.send(result);
+            if let Err(err) = chan.send(result) {
+                tracing::error!("{:?}", err);
+            }
         }
     }
 
@@ -354,8 +358,14 @@ impl PluginCatalogRpcHandler {
     }
 
     pub fn shutdown(&self) {
-        let _ = self.catalog_notification(PluginCatalogNotification::Shutdown);
-        let _ = self.plugin_tx.send(PluginCatalogRpc::Shutdown);
+        if let Err(err) =
+            self.catalog_notification(PluginCatalogNotification::Shutdown)
+        {
+            tracing::error!("{:?}", err);
+        }
+        if let Err(err) = self.plugin_tx.send(PluginCatalogRpc::Shutdown) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     fn catalog_notification(
@@ -443,7 +453,9 @@ impl PluginCatalogRpcHandler {
             check,
             f: Box::new(f),
         };
-        let _ = self.plugin_tx.send(rpc);
+        if let Err(err) = self.plugin_tx.send(rpc) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -465,7 +477,9 @@ impl PluginCatalogRpcHandler {
             path,
             check,
         };
-        let _ = self.plugin_tx.send(rpc);
+        if let Err(err) = self.plugin_tx.send(rpc) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn format_semantic_tokens(
@@ -475,24 +489,32 @@ impl PluginCatalogRpcHandler {
         text: Rope,
         f: Box<dyn RpcCallback<Vec<LineStyle>, RpcError>>,
     ) {
-        let _ = self.plugin_tx.send(PluginCatalogRpc::FormatSemanticTokens {
-            plugin_id,
-            tokens,
-            text,
-            f,
-        });
+        if let Err(err) =
+            self.plugin_tx.send(PluginCatalogRpc::FormatSemanticTokens {
+                plugin_id,
+                tokens,
+                text,
+                f,
+            })
+        {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn did_save_text_document(&self, path: &Path, text: Rope) {
         let text_document =
             TextDocumentIdentifier::new(Url::from_file_path(path).unwrap());
         let language_id = language_id_from_path(path).unwrap_or("").to_string();
-        let _ = self.plugin_tx.send(PluginCatalogRpc::DidSaveTextDocument {
-            language_id,
-            text_document,
-            path: path.into(),
-            text,
-        });
+        if let Err(err) =
+            self.plugin_tx.send(PluginCatalogRpc::DidSaveTextDocument {
+                language_id,
+                text_document,
+                path: path.into(),
+                text,
+            })
+        {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn did_change_text_document(
@@ -508,15 +530,18 @@ impl PluginCatalogRpcHandler {
             rev as i32,
         );
         let language_id = language_id_from_path(path).unwrap_or("").to_string();
-        let _ = self
-            .plugin_tx
-            .send(PluginCatalogRpc::DidChangeTextDocument {
-                language_id,
-                document,
-                delta,
-                text,
-                new_text,
-            });
+        if let Err(err) =
+            self.plugin_tx
+                .send(PluginCatalogRpc::DidChangeTextDocument {
+                    language_id,
+                    document,
+                    delta,
+                    text,
+                    new_text,
+                })
+        {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn get_definition(
@@ -524,9 +549,9 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         position: Position,
         cb: impl FnOnce(PluginId, Result<GotoDefinitionResponse, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = GotoDefinition::METHOD;
@@ -555,9 +580,9 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         position: Position,
         cb: impl FnOnce(PluginId, Result<GotoTypeDefinitionResponse, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = GotoTypeDefinition::METHOD;
@@ -586,11 +611,11 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         item: CallHierarchyItem,
         cb: impl FnOnce(
-                PluginId,
-                Result<Option<Vec<CallHierarchyIncomingCall>>, RpcError>,
-            ) + Clone
-            + Send
-            + 'static,
+            PluginId,
+            Result<Option<Vec<CallHierarchyIncomingCall>>, RpcError>,
+        ) + Clone
+        + Send
+        + 'static,
     ) {
         let method = CallHierarchyIncomingCalls::METHOD;
         let params = CallHierarchyIncomingCallsParams {
@@ -615,9 +640,9 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         position: Position,
         cb: impl FnOnce(PluginId, Result<Option<Vec<CallHierarchyItem>>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = CallHierarchyPrepare::METHOD;
@@ -645,9 +670,9 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         position: Position,
         cb: impl FnOnce(PluginId, Result<Vec<Location>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = References::METHOD;
@@ -674,15 +699,75 @@ impl PluginCatalogRpcHandler {
         );
     }
 
+    pub fn get_lsp_folding_range(
+        &self,
+        path: &Path,
+        cb: impl FnOnce(
+            PluginId,
+            std::result::Result<Option<Vec<FoldingRange>>, RpcError>,
+        ) + Clone
+        + Send
+        + 'static,
+    ) {
+        let uri = Url::from_file_path(path).unwrap();
+        let method = FoldingRangeRequest::METHOD;
+        let params = FoldingRangeParams {
+            text_document: TextDocumentIdentifier { uri },
+            work_done_progress_params: WorkDoneProgressParams::default(),
+            partial_result_params: PartialResultParams::default(),
+        };
+
+        let language_id =
+            Some(language_id_from_path(path).unwrap_or("").to_string());
+        self.send_request_to_all_plugins(
+            method,
+            params,
+            language_id,
+            Some(path.to_path_buf()),
+            cb,
+        );
+    }
+
+    pub fn go_to_implementation(
+        &self,
+        path: &Path,
+        position: Position,
+        cb: impl FnOnce(PluginId, Result<Option<GotoImplementationResponse>, RpcError>)
+        + Clone
+        + Send
+        + 'static,
+    ) {
+        let uri = Url::from_file_path(path).unwrap();
+        let method = GotoImplementation::METHOD;
+        let params = GotoTypeDefinitionParams {
+            text_document_position_params: TextDocumentPositionParams {
+                text_document: TextDocumentIdentifier { uri },
+                position,
+            },
+            work_done_progress_params: WorkDoneProgressParams::default(),
+            partial_result_params: PartialResultParams::default(),
+        };
+
+        let language_id =
+            Some(language_id_from_path(path).unwrap_or("").to_string());
+        self.send_request_to_all_plugins(
+            method,
+            params,
+            language_id,
+            Some(path.to_path_buf()),
+            cb,
+        );
+    }
+
     pub fn get_code_actions(
         &self,
         path: &Path,
         position: Position,
         diagnostics: Vec<Diagnostic>,
         cb: impl FnOnce(PluginId, Result<CodeActionResponse, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = CodeActionRequest::METHOD;
@@ -715,9 +800,9 @@ impl PluginCatalogRpcHandler {
         &self,
         path: &Path,
         cb: impl FnOnce(PluginId, Result<Option<Vec<CodeLens>>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = CodeLensRequest::METHOD;
@@ -739,14 +824,33 @@ impl PluginCatalogRpcHandler {
         );
     }
 
+    pub fn get_code_lens_resolve(
+        &self,
+        path: &Path,
+        code_lens: &CodeLens,
+        cb: impl FnOnce(PluginId, Result<CodeLens, RpcError>) + Clone + Send + 'static,
+    ) {
+        let method = CodeLensResolve::METHOD;
+        let language_id =
+            Some(language_id_from_path(path).unwrap_or("").to_string());
+
+        self.send_request_to_all_plugins(
+            method,
+            code_lens,
+            language_id,
+            Some(path.to_path_buf()),
+            cb,
+        );
+    }
+
     pub fn get_inlay_hints(
         &self,
         path: &Path,
         range: Range,
         cb: impl FnOnce(PluginId, Result<Vec<InlayHint>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = InlayHintRequest::METHOD;
@@ -772,9 +876,9 @@ impl PluginCatalogRpcHandler {
         position: Position,
         trigger_kind: InlineCompletionTriggerKind,
         cb: impl FnOnce(PluginId, Result<InlineCompletionResponse, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = InlineCompletionRequest::METHOD;
@@ -804,9 +908,9 @@ impl PluginCatalogRpcHandler {
         &self,
         path: &Path,
         cb: impl FnOnce(PluginId, Result<DocumentSymbolResponse, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = DocumentSymbolRequest::METHOD;
@@ -830,9 +934,9 @@ impl PluginCatalogRpcHandler {
         &self,
         query: String,
         cb: impl FnOnce(PluginId, Result<Vec<SymbolInformation>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let method = WorkspaceSymbolRequest::METHOD;
         let params = WorkspaceSymbolParams {
@@ -847,9 +951,9 @@ impl PluginCatalogRpcHandler {
         &self,
         path: &Path,
         cb: impl FnOnce(PluginId, Result<Vec<TextEdit>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = Formatting::METHOD;
@@ -878,9 +982,9 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         position: Position,
         cb: impl FnOnce(PluginId, Result<PrepareRenameResponse, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = PrepareRenameRequest::METHOD;
@@ -905,9 +1009,9 @@ impl PluginCatalogRpcHandler {
         position: Position,
         new_name: String,
         cb: impl FnOnce(PluginId, Result<WorkspaceEdit, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = Rename::METHOD;
@@ -934,9 +1038,9 @@ impl PluginCatalogRpcHandler {
         &self,
         path: &Path,
         cb: impl FnOnce(PluginId, Result<SemanticTokens, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = SemanticTokensFullRequest::METHOD;
@@ -961,9 +1065,9 @@ impl PluginCatalogRpcHandler {
         path: &Path,
         positions: Vec<Position>,
         cb: impl FnOnce(PluginId, Result<Vec<SelectionRange>, RpcError>)
-            + Clone
-            + Send
-            + 'static,
+        + Clone
+        + Send
+        + 'static,
     ) {
         let uri = Url::from_file_path(path).unwrap();
         let method = SelectionRangeRequest::METHOD;
@@ -1039,8 +1143,8 @@ impl PluginCatalogRpcHandler {
             params,
             language_id,
             Some(path.to_path_buf()),
-            move |plugin_id, result| {
-                if let Ok(value) = result {
+            move |plugin_id, result| match result {
+                Ok(value) => {
                     if let Ok(resp) =
                         serde_json::from_value::<CompletionResponse>(value)
                     {
@@ -1048,6 +1152,9 @@ impl PluginCatalogRpcHandler {
                             .completion_response(request_id, input, resp, plugin_id);
                     }
                 }
+                Err(err) => {
+                    tracing::error!("{:?}", err);
+                }
             },
         );
     }
@@ -1118,14 +1225,17 @@ impl PluginCatalogRpcHandler {
             language_id,
             Some(path.to_path_buf()),
             true,
-            move |plugin_id, result| {
-                if let Ok(value) = result {
+            move |plugin_id, result| match result {
+                Ok(value) => {
                     if let Ok(resp) = serde_json::from_value::<SignatureHelp>(value)
                     {
                         core_rpc
                             .signature_help_response(request_id, resp, plugin_id);
                     }
                 }
+                Err(err) => {
+                    tracing::error!("{:?}", err);
+                }
             },
         );
     }
@@ -1175,14 +1285,18 @@ impl PluginCatalogRpcHandler {
     ) {
         match Url::from_file_path(path) {
             Ok(path) => {
-                let _ = self.plugin_tx.send(PluginCatalogRpc::DidOpenTextDocument {
-                    document: TextDocumentItem::new(
-                        path,
-                        language_id,
-                        version,
-                        text,
-                    ),
-                });
+                if let Err(err) =
+                    self.plugin_tx.send(PluginCatalogRpc::DidOpenTextDocument {
+                        document: TextDocumentItem::new(
+                            path,
+                            language_id,
+                            version,
+                            text,
+                        ),
+                    })
+                {
+                    tracing::error!("{:?}", err);
+                }
             }
             Err(_) => {
                 tracing::error!("Failed to parse URL from file path: {path:?}");
@@ -1226,7 +1340,9 @@ impl PluginCatalogRpcHandler {
                 }
             }),
         };
-        let _ = self.plugin_tx.send(rpc);
+        if let Err(err) = self.plugin_tx.send(rpc) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn remove_volt(&self, volt: VoltMetadata) {
@@ -1243,7 +1359,9 @@ impl PluginCatalogRpcHandler {
                 }
             }),
         };
-        let _ = self.plugin_tx.send(rpc);
+        if let Err(err) = self.plugin_tx.send(rpc) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn reload_volt(&self, volt: VoltMetadata) -> Result<()> {
@@ -1361,11 +1479,13 @@ impl PluginCatalogRpcHandler {
         reference: usize,
         f: impl FnOnce(Result<Vec<dap_types::Variable>, RpcError>) + Send + 'static,
     ) {
-        let _ = self.plugin_tx.send(PluginCatalogRpc::DapVariable {
+        if let Err(err) = self.plugin_tx.send(PluginCatalogRpc::DapVariable {
             dap_id,
             reference,
             f: Box::new(f),
-        });
+        }) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn dap_get_scopes(
@@ -1373,15 +1493,17 @@ impl PluginCatalogRpcHandler {
         dap_id: DapId,
         frame_id: usize,
         f: impl FnOnce(
-                Result<Vec<(dap_types::Scope, Vec<dap_types::Variable>)>, RpcError>,
-            ) + Send
-            + 'static,
+            Result<Vec<(dap_types::Scope, Vec<dap_types::Variable>)>, RpcError>,
+        ) + Send
+        + 'static,
     ) {
-        let _ = self.plugin_tx.send(PluginCatalogRpc::DapGetScopes {
+        if let Err(err) = self.plugin_tx.send(PluginCatalogRpc::DapGetScopes {
             dap_id,
             frame_id,
             f: Box::new(f),
-        });
+        }) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn register_debugger_type(
@@ -1390,13 +1512,15 @@ impl PluginCatalogRpcHandler {
         program: String,
         args: Option<Vec<String>>,
     ) {
-        let _ = self.catalog_notification(
+        if let Err(err) = self.catalog_notification(
             PluginCatalogNotification::RegisterDebuggerType {
                 debugger_type,
                 program,
                 args,
             },
-        );
+        ) {
+            tracing::error!("{:?}", err);
+        }
     }
 }
 
@@ -1457,7 +1581,9 @@ pub fn download_volt(volt: &VoltInfo) -> Result<VoltMetadata> {
     let plugin_dir = Directory::plugins_directory()
         .ok_or_else(|| anyhow!("can't get plugin directory"))?
         .join(id.to_string());
-    let _ = fs::remove_dir_all(&plugin_dir);
+    if let Err(err) = fs::remove_dir_all(&plugin_dir) {
+        tracing::error!("{:?}", err);
+    }
     fs::create_dir_all(&plugin_dir)?;
 
     if is_zstd {
@@ -1490,7 +1616,11 @@ pub fn install_volt(
     let local_catalog_rpc = catalog_rpc.clone();
     let local_meta = meta.clone();
 
-    let _ = start_volt(workspace, configurations, local_catalog_rpc, local_meta);
+    if let Err(err) =
+        start_volt(workspace, configurations, local_catalog_rpc, local_meta)
+    {
+        tracing::error!("{:?}", err);
+    }
     let icon = volt_icon(&meta);
     catalog_rpc.core_rpc.volt_installed(meta, icon);
     Ok(())
@@ -1537,6 +1667,14 @@ fn client_capabilities() -> ClientCapabilities {
     // https://github.com/rust-lang/rust-analyzer/blob/master/docs/dev/lsp-extensions.md#server-status
     let mut experimental = Map::new();
     experimental.insert("serverStatusNotification".into(), true.into());
+    let command_vec = ["rust-analyzer.runSingle", "rust-analyzer.debugSingle"]
+        .map(Value::from)
+        .to_vec();
+
+    let mut commands = Map::new();
+    experimental.insert("serverStatusNotification".into(), true.into());
+    commands.insert("commands".into(), command_vec.into());
+    experimental.insert("commands".into(), commands.into());
     ClientCapabilities {
         text_document: Some(TextDocumentClientCapabilities {
             synchronization: Some(TextDocumentSyncClientCapabilities {
@@ -1627,6 +1765,13 @@ fn client_capabilities() -> ClientCapabilities {
                 hierarchical_document_symbol_support: Some(true),
                 ..Default::default()
             }),
+            folding_range: Some(FoldingRangeClientCapabilities {
+                dynamic_registration: Some(false),
+                range_limit: None,
+                line_folding_only: Some(false),
+                folding_range_kind: None,
+                folding_range: None,
+            }),
             ..Default::default()
         }),
         window: Some(WindowClientCapabilities {
