@@ -3,49 +3,51 @@ use std::{
     collections::HashMap,
     path::{Path, PathBuf},
     sync::{
-        atomic::{AtomicU64, Ordering},
         Arc,
+        atomic::{AtomicU64, Ordering},
     },
     thread,
 };
 
-use anyhow::{anyhow, Result};
+use anyhow::{Result, anyhow};
 use crossbeam_channel::{Receiver, Sender};
 use dyn_clone::DynClone;
 use floem_editor_core::buffer::rope_text::{RopeText, RopeTextRef};
 use jsonrpc_lite::{Id, JsonRpc, Params};
 use lapce_core::{encoding::offset_utf16_to_utf8, rope_text_pos::RopeTextPosition};
 use lapce_rpc::{
+    RpcError,
     core::{CoreRpcHandler, ServerStatusParams},
     plugin::{PluginId, VoltID},
     style::{LineStyle, Style},
-    RpcError,
 };
 use lapce_xi_rope::{Rope, RopeDelta};
 use lsp_types::{
+    CancelParams, CodeActionProviderCapability, DidChangeTextDocumentParams,
+    DidSaveTextDocumentParams, DocumentSelector, FoldingRangeProviderCapability,
+    HoverProviderCapability, ImplementationProviderCapability, InitializeResult,
+    LogMessageParams, MessageType, OneOf, ProgressParams, PublishDiagnosticsParams,
+    Range, Registration, RegistrationParams, SemanticTokens, SemanticTokensLegend,
+    SemanticTokensServerCapabilities, ServerCapabilities, ShowMessageParams,
+    TextDocumentContentChangeEvent, TextDocumentIdentifier,
+    TextDocumentSaveRegistrationOptions, TextDocumentSyncCapability,
+    TextDocumentSyncKind, TextDocumentSyncSaveOptions,
+    VersionedTextDocumentIdentifier,
     notification::{
-        DidChangeTextDocument, DidOpenTextDocument, DidSaveTextDocument,
+        Cancel, DidChangeTextDocument, DidOpenTextDocument, DidSaveTextDocument,
         Initialized, LogMessage, Notification, Progress, PublishDiagnostics,
         ShowMessage,
     },
     request::{
         CallHierarchyIncomingCalls, CallHierarchyPrepare, CodeActionRequest,
-        CodeActionResolveRequest, CodeLensRequest, Completion,
-        DocumentSymbolRequest, Formatting, GotoDefinition, GotoTypeDefinition,
-        HoverRequest, Initialize, InlayHintRequest, InlineCompletionRequest,
-        PrepareRenameRequest, References, RegisterCapability, Rename,
-        ResolveCompletionItem, SelectionRangeRequest, SemanticTokensFullRequest,
-        SignatureHelpRequest, WorkDoneProgressCreate, WorkspaceSymbolRequest,
+        CodeActionResolveRequest, CodeLensRequest, CodeLensResolve, Completion,
+        DocumentSymbolRequest, FoldingRangeRequest, Formatting, GotoDefinition,
+        GotoImplementation, GotoTypeDefinition, HoverRequest, Initialize,
+        InlayHintRequest, InlineCompletionRequest, PrepareRenameRequest, References,
+        RegisterCapability, Rename, ResolveCompletionItem, SelectionRangeRequest,
+        SemanticTokensFullRequest, SignatureHelpRequest, WorkDoneProgressCreate,
+        WorkspaceSymbolRequest,
     },
-    CodeActionProviderCapability, DidChangeTextDocumentParams,
-    DidSaveTextDocumentParams, DocumentSelector, HoverProviderCapability,
-    InitializeResult, LogMessageParams, MessageType, OneOf, ProgressParams,
-    PublishDiagnosticsParams, Range, Registration, RegistrationParams,
-    SemanticTokens, SemanticTokensLegend, SemanticTokensServerCapabilities,
-    ServerCapabilities, ShowMessageParams, TextDocumentContentChangeEvent,
-    TextDocumentIdentifier, TextDocumentSaveRegistrationOptions,
-    TextDocumentSyncCapability, TextDocumentSyncKind, TextDocumentSyncSaveOptions,
-    VersionedTextDocumentIdentifier,
 };
 use parking_lot::Mutex;
 use psp_types::{
@@ -59,8 +61,8 @@ use serde::Serialize;
 use serde_json::Value;
 
 use super::{
-    lsp::{DocumentFilter, LspClient},
     PluginCatalogRpcHandler,
+    lsp::{DocumentFilter, LspClient},
 };
 
 pub enum ResponseHandler<Resp, Error> {
@@ -72,7 +74,9 @@ impl<Resp, Error> ResponseHandler<Resp, Error> {
     pub fn invoke(self, result: Result<Resp, Error>) {
         match self {
             ResponseHandler::Chan(tx) => {
-                let _ = tx.send(result);
+                if let Err(err) = tx.send(result) {
+                    tracing::error!("{:?}", err);
+                }
             }
             ResponseHandler::Callback(f) => f.call(result),
         }
@@ -101,6 +105,7 @@ impl<Resp, Error, F: Send + FnOnce(Result<Resp, Error>)> RpcCallback<Resp, Error
     }
 }
 
+#[allow(clippy::large_enum_variant)]
 pub enum PluginHandlerNotification {
     Initialize,
     InitializeResult(InitializeResult),
@@ -109,6 +114,7 @@ pub enum PluginHandlerNotification {
     SpawnedPluginLoaded { plugin_id: PluginId },
 }
 
+#[allow(clippy::large_enum_variant)]
 pub enum PluginServerRpc {
     Shutdown,
     Handler(PluginHandlerNotification),
@@ -189,18 +195,24 @@ impl ResponseSender {
             code: 0,
             message: e.to_string(),
         });
-        let _ = self.tx.send(result);
+        if let Err(err) = self.tx.send(result) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn send_null(&self) {
-        let _ = self.tx.send(Ok(Value::Null));
+        if let Err(err) = self.tx.send(Ok(Value::Null)) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn send_err(&self, code: i64, message: impl Into<String>) {
-        let _ = self.tx.send(Err(RpcError {
+        if let Err(err) = self.tx.send(Err(RpcError {
             code,
             message: message.into(),
-        }));
+        })) {
+            tracing::error!("{:?}", err);
+        }
     }
 }
 
@@ -308,11 +320,15 @@ impl PluginServerRpcHandler {
     }
 
     fn send_server_rpc(&self, msg: JsonRpc) {
-        let _ = self.io_tx.send(msg);
+        if let Err(err) = self.io_tx.send(msg) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     pub fn handle_rpc(&self, rpc: PluginServerRpc) {
-        let _ = self.rpc_tx.send(rpc);
+        if let Err(err) = self.rpc_tx.send(rpc) {
+            tracing::error!("{:?}", err);
+        }
     }
 
     /// Send a notification.  
@@ -329,12 +345,14 @@ impl PluginServerRpcHandler {
         let method = method.into();
 
         if check {
-            let _ = self.rpc_tx.send(PluginServerRpc::ServerNotification {
+            if let Err(err) = self.rpc_tx.send(PluginServerRpc::ServerNotification {
                 method,
                 params,
                 language_id,
                 path,
-            });
+            }) {
+                tracing::error!("{:?}", err);
+            }
         } else {
             self.send_server_notification(&method, params);
         }
@@ -402,14 +420,16 @@ impl PluginServerRpcHandler {
         let id = self.id.fetch_add(1, Ordering::Relaxed);
         let params = Params::from(serde_json::to_value(params).unwrap());
         if check {
-            let _ = self.rpc_tx.send(PluginServerRpc::ServerRequest {
+            if let Err(err) = self.rpc_tx.send(PluginServerRpc::ServerRequest {
                 id: Id::Num(id as i64),
                 method,
                 params,
                 language_id,
                 path,
                 rh,
-            });
+            }) {
+                tracing::error!("{:?}", err);
+            }
         } else {
             self.send_server_request(Id::Num(id as i64), &method, params, rh);
         }
@@ -749,6 +769,36 @@ impl PluginHostHandler {
                     OneOf::Right(_) => true,
                 })
                 .unwrap_or(false),
+            GotoImplementation::METHOD => self
+                .server_capabilities
+                .implementation_provider
+                .as_ref()
+                .map(|r| match r {
+                    ImplementationProviderCapability::Simple(is_capable) => {
+                        *is_capable
+                    }
+                    ImplementationProviderCapability::Options(_) => {
+                        // todo
+                        false
+                    }
+                })
+                .unwrap_or(false),
+            FoldingRangeRequest::METHOD => self
+                .server_capabilities
+                .folding_range_provider
+                .as_ref()
+                .map(|r| match r {
+                    FoldingRangeProviderCapability::Simple(support) => *support,
+                    FoldingRangeProviderCapability::FoldingProvider(_) => {
+                        // todo
+                        true
+                    }
+                    FoldingRangeProviderCapability::Options(_) => {
+                        // todo
+                        true
+                    }
+                })
+                .unwrap_or(false),
             CodeActionRequest::METHOD => self
                 .server_capabilities
                 .code_action_provider
@@ -796,6 +846,12 @@ impl PluginHostHandler {
             CodeLensRequest::METHOD => {
                 self.server_capabilities.code_lens_provider.is_some()
             }
+            CodeLensResolve::METHOD => self
+                .server_capabilities
+                .code_lens_provider
+                .as_ref()
+                .and_then(|x| x.resolve_provider)
+                .unwrap_or(false),
             CallHierarchyPrepare::METHOD => {
                 self.server_capabilities.call_hierarchy_provider.is_some()
             }
@@ -846,7 +902,9 @@ impl PluginHostHandler {
 
     fn register_capabilities(&mut self, registrations: Vec<Registration>) {
         for registration in registrations {
-            let _ = self.register_capability(registration);
+            if let Err(err) = self.register_capability(registration) {
+                tracing::error!("{:?}", err);
+            }
         }
     }
 
@@ -946,7 +1004,7 @@ impl PluginHostHandler {
                 self.spawned_lsp
                     .insert(plugin_id, SpawnedLspInfo { resp: Some(resp) });
                 thread::spawn(move || {
-                    let _ = LspClient::start(
+                    if let Err(err) = LspClient::start(
                         catalog_rpc,
                         params.document_selector,
                         workspace,
@@ -958,7 +1016,9 @@ impl PluginHostHandler {
                         params.server_uri,
                         params.server_args,
                         params.options,
-                    );
+                    ) {
+                        tracing::error!("{:?}", err);
+                    }
                 });
             }
             SendLspNotification::METHOD => {
@@ -1053,7 +1113,7 @@ impl PluginHostHandler {
                 let volt_id = self.volt_id.clone();
                 let volt_display_name = self.volt_display_name.clone();
                 thread::spawn(move || {
-                    let _ = LspClient::start(
+                    if let Err(err) = LspClient::start(
                         catalog_rpc,
                         params.document_selector,
                         workspace,
@@ -1065,7 +1125,9 @@ impl PluginHostHandler {
                         params.server_uri,
                         params.server_args,
                         params.options,
-                    );
+                    ) {
+                        tracing::error!("{:?}", err);
+                    }
                 });
             }
             PublishDiagnostics::METHOD => {
@@ -1095,6 +1157,11 @@ impl PluginHostHandler {
                     ),
                 );
             }
+            Cancel::METHOD => {
+                let params: CancelParams =
+                    serde_json::from_value(serde_json::to_value(params)?)?;
+                self.catalog_rpc.core_rpc.cancel(params);
+            }
             "experimental/serverStatus" => {
                 let param: ServerStatusParams =
                     serde_json::from_value(serde_json::to_value(params)?)?;
